@@ -1,4 +1,5 @@
 # --------------- Scraping --------------- #
+
 class ScrapeError(Exception):
     """An issue while scraping the page."""
     pass
@@ -38,8 +39,8 @@ class DefaultConfigNotFound(ConfigError):
     pass
 
 
-class UserConfigNotFound(ConfigError):
-    """User config file could not be found."""
+class ConfigValueMissing(ConfigError):
+    """A required config value is missing."""
     pass
 
 
